#include <iostream>
#include <vector>
#include <functional>

#define ENDL '\n'

namespace {
using adj_list = std::vector<std::vector<int>>;
	
auto find_bridges(adj_list& graph) {
	auto n = graph.size();

	auto timer = 0;
	std::vector<bool> visited(n, false);
	std::vector<int> time_in(n, -1);
	std::vector<int> time_low(n, -1);

	auto res = 0;
	
	std::function<void(int, int)> dfs;
	dfs = [&](int v, int p) {
		visited[v] = true;
		
		time_in[v] = time_low[v] = timer++;
		for (auto to : graph[v]) {
			if (to == p) {
				continue;
			}
			
			if (visited[to]) {
				time_low[v] = std::min(time_low[v], time_in[to]);
			} else {
				dfs(to, v);
				time_low[v] = std::min(time_low[v], time_low[to]);
				
				if (time_low[to] > time_in[v]) {
					++res;
				}
			}
		}
	};
	
	for (auto i = 1; i < n; ++i) {
		if (!visited[i]) {
			dfs(i, -1);
		}
	}
	
	return res;
}
} // namespace

int main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(nullptr);
	std::cout.tie(nullptr);
	
	int n, m;
	std::cin >> n >> m;
	
	adj_list graph;
	graph.resize(n + 1);
	
	int i, j;
	while (m--) {
		std::cin >> i >> j;
		
		graph[i].emplace_back(j);
		graph[j].emplace_back(i);
	}
	
	std::cout << find_bridges(graph) << ENDL;
		
	return 0;
}